srsgui.ui.commandtree package
==============================

``srsgui.ui.commandtree`` package visualizes an instance of
:class:`Instrument <srsgui.inst.instrument.Instrument>` class
containing multiple components and commands using
`Qt Model/View programming. <model_view_programming_>`_

The visualization helps the hierarchical structure of a command
can be used more easily in the command terminal and writing the Python scripts.

.. automodule:: srsgui.ui.commandtree
   :members:
   :undoc-members:
   :show-inheritance:

srsgui.ui.commandtree.commanditem module
-----------------------------------------

.. automodule:: srsgui.ui.commandtree.commanditem
   :members:
   :undoc-members:
   :show-inheritance:

srsgui.ui.commandtree.commandmodel module
------------------------------------------

.. automodule:: srsgui.ui.commandtree.commandmodel
   :members:
   :undoc-members:
   :show-inheritance:

srsgui.ui.commandtree.commandhandler module
--------------------------------------------

.. automodule:: srsgui.ui.commandtree.commandhandler
   :members:
   :undoc-members:
   :show-inheritance:

srsgui.ui.commandtree.commanddelegate module
---------------------------------------------

.. automodule:: srsgui.ui.commandtree.commanddelegate
   :members:
   :undoc-members:
   :show-inheritance:

srsgui.ui.commandtree.commandspinbox module
--------------------------------------------

.. automodule:: srsgui.ui.commandtree.commandspinbox
   :members:
   :undoc-members:
   :show-inheritance:

srsgui.ui.commandtree.commandtreeview module
---------------------------------------------

.. automodule:: srsgui.ui.commandtree.commandtreeview
   :members:
   :undoc-members:
   :show-inheritance:

srsgui.ui.commandtree.commandtreewidget module
-----------------------------------------------

.. automodule:: srsgui.ui.commandtree.commandtreewidget
   :members:
   :undoc-members:
   :show-inheritance:

.. _model_view_programming: https://doc.qt.io/qt-6/model-view-programming.html